%global major 1
%define libname %mklibname flashrom %major
%define devname %mklibname -d flashrom
Name:		flashrom
Version:	1.2
Release:	%mkrel 4
Summary:	Simple program for reading/writing flash chips content
Group:		System/Libraries
License:	GPLv2
URL:		https://flashrom.org

Source0:	https://download.flashrom.org/releases/%{name}-v%{version}.tar.bz2
Source1:	https://download.flashrom.org/releases/%{name}-v%{version}.tar.bz2.asc
Source2:	https://keys.openpgp.org/vks/v1/by-fingerprint/gpgkey-58A4868B25C7CFD662FB0132A3EB95B8D9780F68.gpg

# upstream already: https://review.coreboot.org/c/flashrom/+/38939
Patch0:    0001-Install-the-man-file-when-using-meson-as-a-buildsyst.patch

BuildRequires:	gnupg2
BuildRequires:	gcc
BuildRequires:	meson
BuildRequires:	pciutils-devel
BuildRequires:	libftdi-devel
BuildRequires:	libusb-devel
# Used for new programmers (libusb0 will eventually be removed)
BuildRequires:	libusbx-devel
BuildRequires:	systemd
BuildRequires:	zlib-devel
%ifarch %{ix86} x86_64 aarch64
BuildRequires:	dmidecode
Requires:	dmidecode
%endif
Requires:	udev
# see rhbz #495226
ExcludeArch:	s390 s390x


%description
flashrom is a utility for identifying, reading, writing, verifying and erasing
flash chips. It is designed to flash BIOS/EFI/coreboot/firmware/optionROM
images on mainboards, network/graphics/storage controller cards, and various
other programmer devices.

%package -n %libname
Summary: $prog
Group: System/Libraries

%description -n %libname
Library for flashrom

%package -n %devname
Group: Development/C
Summary: Development package for %{name}
Requires: %{libname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}

%description -n %devname
Files for development with %{name}.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -p1 -n %{name}-v%{version}
# Replace GROUP="plugdev" specifiers with TAG+="uaccess"
sed -e 's/MODE="[0-9]*", GROUP="plugdev"/TAG+="uaccess"/g' util/z60_flashrom.rules -i

%build
%meson \
%ifarch %{ix86} x86_64
  -Dconfig_internal=true
%else
  -Dconfig_atahpt=false \
  -Dconfig_atapromise=false \
  -Dconfig_atavia=false \
  -Dconfig_drkaiser=false \
  -Dconfig_gfxnvidia=false \
  -Dconfig_it8212=false \
  -Dconfig_nic3com=false \
  -Dconfig_nicintel_eeprom=false \
  -Dconfig_nicintel=false \
  -Dconfig_nicintel_spi=false \
  -Dconfig_nicnatsemi=false \
  -Dconfig_nicrealtek=false \
  -Dconfig_ogp_spi=false \
  -Dconfig_rayer_spi=false \
  -Dconfig_satamv=false \
  -Dconfig_satasii=false \
  -Dconfig_internal=false
%endif

%meson_build

%if 0%{?enable_tests}
%check
%meson_test
%endif

%install
%meson_install

install -D -p -m 0644 util/z60_flashrom.rules %{buildroot}/%{_udevrulesdir}/60_flashrom.rules

%files
%license COPYING
%doc README
%{_sbindir}/%{name}
%{_mandir}/man8/%{name}.*
%{_udevrulesdir}/60_flashrom.rules

%files -n %libname
%{_libdir}/libflashrom.so.%{major}
%{_libdir}/libflashrom.so.%{major}.0.0

%files -n %devname
%{_includedir}/libflashrom.h
%{_libdir}/libflashrom.so
%{_libdir}/pkgconfig/flashrom.pc



%changelog
* Wed Dec 14 2022 mrambo3501 <mrambo3501> 1.2-4.mga9
+ Revision: 1921901
- fix Source2 in spec
+ tv <tv>
- Switch source file verification to keys.openpgp.org
- Perform source file verification during %%prep
+ neoclust <neoclust>
- Rebuild because of broken dependancies
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Apr 05 2020 tv <tv> 1.2-2.mga8
+ Revision: 1564902
- add devel provides

* Thu Mar 05 2020 tv <tv> 1.2-1.mga8
+ Revision: 1553973
- imported package flashrom


* Thu Mar 05 2020 Thierry Vignaud <tv@mageia.org> 1.2-1.mga8
- import from FC
